Os módulos "Python" listados em "Módulos "Python"" tem dependências que não são referenciadas por outros pacotes no BLFS. Essas dependências estão listadas aqui. Eles não serão atualizados regularmente, a menos que uma versão mais recente seja necessária.
No BLFS, normalmente nós construímos e instalamos módulos Python
3 com pip3. Por
favor, tome cuidado de que os comandos pip3 install no livro deveriam
ser executados como root, a menos
que seja para um ambiente virtual Python. Executar-se o
pip3 install como
um(a) usante não-root
possivelmente pareça funcionar bem, mas causará o módulo
instalado ficar inacessível por outros(as) usantes.
pip3 install não
reinstalará um módulo já instalado por padrão. Para usar o
comando pip3
install para atualizar um módulo (por exemplo, de
meson-0.61.3 para meson-0.62.0), insira --upgrade na linha de comando. Se
for realmente necessário desatualizar um módulo ou reinstalar a
mesma versão por algum motivo, insira --force-reinstall na linha de
comando.
O pacote "Alabaster" é um tema para o sistema de documentação "sphinx". Embora desenvolvido separadamente, é o tema padrão para "Sphinx".
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/a/alabaster/alabaster-1.0.0.tar.gz
Soma de verificação MD5 da transferência: c6c2173e5565fb12f08bef410ea50f72
Tamanho da transferência: 24 KB
Espaço em disco estimado exigido: 160 KB
Tempo de construção estimado: menos que 0,1 UPC
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Esse pacote não vem com uma suíte de teste.
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user alabaster
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O pacote "Babel" é uma coleção integrada de utilitários que auxiliam na internacionalização e localização de aplicações "Python", com ênfase em aplicações baseadas na web.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/B/Babel/babel-2.18.0.tar.gz
Soma de verificação MD5 da transferência: b5ea9705c2ad6f8c630e4a66d3dd2cfa
Tamanho da transferência: 9,5 MB
Espaço em disco estimado exigido: 129 MB (com testes)
Tempo de construção estimado: 0,1 UPC (com testes)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user Babel
Supondo que pytest-9.1.1 esteja instalado, mas as outras dependências opcionais não estejam, a instalação pode ser testada com os seguintes comandos:
python3 -m venv --system-site-packages testenv && source testenv/bin/activate && pip3 install pytest-cov freezegun && python3 /usr/bin/pytest deactivate
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--system-site-packages:
Permita que o módulo venv do Python3 acesse o diretório /usr/lib/python3.14/site-packages do sistema
instalado.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O módulo certifi fornece uma coleção cuidadosamente selecionada de Certificados Raiz da Mozilla para validar a confiabilidade dos certificados SSL enquanto verifica a identidade dos dispositivos TLS.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/c/certifi/certifi-2026.6.17.tar.gz
Soma de verificação MD5 da transferência: 1af47cd1635599db1f2e598ae6c4d751
Tamanho da transferência: 132 KB
Espaço em disco estimado exigido: 700 KB
Tempo de construção estimado: menos que 0,1 UPC
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user certifi
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
"Chardet" é um detector universal de codificação de caracteres.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/c/chardet/chardet-5.2.0.tar.gz
Soma de verificação MD5 da transferência: cc2d8cc9a751641463b4f7cfecad2ffa
Tamanho da transferência: 768 KB
Espaço em disco estimado exigido: 63 MB (adicionar 12 MB para os testes)
Tempo de construção estimado: menos que 0,1 UPC (0,8 UPC para testes)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user chardet
Para testar a instalação, emita pytest.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
A biblioteca charset-normalizer ajuda com leitura de texto originário de uma codificação de caracteres desconhecida.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/c/charset-normalizer/charset_normalizer-3.4.7.tar.gz
Soma de verificação MD5 da transferência: 68805886064d248d2e5205fd11112d85
Tamanho da transferência: 144 KB
Espaço em disco estimado exigido: 1,1 MB (adicionar 15 MB para os testes)
Tempo de construção estimado: menos que 0,1 UPC (com testes)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user charset-normalizer
Supondo que pytest-9.1.1 esteja instalado, mas as outras dependências opcionais não estejam, a instalação pode ser testada com os seguintes comandos:
python3 -m venv --system-site-packages testenv && source testenv/bin/activate && pip3 install pytest-cov && python3 /usr/bin/pytest && deactivate
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--system-site-packages:
Permita que o módulo venv do Python3 acesse o diretório /usr/lib/python3.14/site-packages do sistema
instalado.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
"Commonmark" analisador "Python" para a especificação "CommonMark Markdown".
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/c/commonmark/commonmark-0.9.2.tar.gz
Soma de verificação MD5 da transferência: b0231bf53ac7261f0f47d268b77b667f
Tamanho da transferência: 96 KB
Espaço em disco estimado exigido: 1,3 MB (adicionar 30 MB para os testes)
Tempo de construção estimado: menos que 0,1 UPC (0,1 UPC para testes)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user commonmark
Supondo que "pytest-9.1.1" esteja instalado e a outra dependência opcional não esteja, a instalação pode ser testada com:
python3 -m venv --system-site-packages testenv && source testenv/bin/activate && pip3 install hypothesis && python3 /usr/bin/pytest commonmark/tests/unit_tests.py python3 commonmark/tests/run_spec_tests.py deactivate
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--system-site-packages:
Permita que o módulo venv do Python3 acesse o diretório /usr/lib/python3.14/site-packages do sistema
instalado.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
"Hatchling" é uma estrutura de retaguarda de construção extensível e compatível com padrões para módulos "Python".
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/h/hatchling/hatchling-1.32.0.tar.gz
Soma de verificação MD5 da transferência: e5870c28ce4403c12b3d9a4a4f8866fe
Tamanho da transferência: 56 KB
Espaço em disco estimado exigido: 1,1 MB
Tempo de construção estimado: menos que 0,1 UPC
pathspec-1.1.1, pluggy-1.6.0, tomlkit-0.15.1 e trove-classifiers-2026.6.1.19
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Esse pacote não vem com uma suíte de teste funcional.
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user hatchling
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
Hatch-Fancy-Pypi-Readme é um plugin de hachura que preenche o campo leia-me nos metadados de um módulo Python a partir dos arquivos de documentação da linguagem de marcação do módulo.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/h/hatch-fancy-pypi-readme/hatch_fancy_pypi_readme-25.1.0.tar.gz
Soma de verificação MD5 da transferência: 8e1ed2416887685adc1c909ed4fb63cb
Tamanho da transferência: 32 KB
Espaço em disco estimado exigido: 388 KB
Tempo de construção estimado: menos que 0,1 UPC
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user hatch-fancy-pypi-readme
Para testar a instalação, emita: pytest.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
Hatch_vcs é um plugin Hatch para versionamento com vários Sistemas de Controle de Versão ( VCS ).
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/h/hatch-vcs/hatch_vcs-0.5.0.tar.gz
Soma de verificação MD5 da transferência: 9a22a9f7203783e526959d34510a9672
Tamanho da transferência: 9,9 KB
Espaço em disco estimado exigido: 436 KB (com testes)
Tempo de construção estimado: menos que 0,1 UPC (com testes)
hatchling-1.32.0 e setuptools_scm-10.1.2
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user hatch_vcs
Para testar a instalação, emita (HOME= impede o arquivo .gitconfig no diretório inicial de interferir
nos testes): HOME=
pytest.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O módulo "Idna" fornece suporte para o protocolo "Internationalized Domain Names in Applications" ("IDNA"), conforme especificado na "RFC" 5891.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/i/idna/idna-3.18.tar.gz
Soma de verificação MD5 da transferência: 64359467ec86d86e398b1ae614e5718c
Tamanho da transferência: 196 KB
Espaço em disco estimado exigido: 4,8 MB (com testes)
Tempo de construção estimado: menos que 0,1 UPC (com testes)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user idna
Para testar a instalação, execute pytest.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O pacote "imagesize" analisa os cabeçalhos dos arquivos de imagem e retorna o tamanho e o "DPI" da imagem. Funciona com formatos "JPEG"/"JPEG 2000"/"PNG"/"GIF"/"TIFF"/"SVG"/"Netpbm"/"WebP".
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/i/imagesize/imagesize-1.4.1.tar.gz
Soma de verificação MD5 da transferência: 5a40586a25c07e1a8f16f6267252c321
Tamanho da transferência: 1,2 MB
Espaço em disco estimado exigido: 1,8 MB (com testes)
Tempo de construção estimado: menos que 0,1 UPC (com testes)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user imagesize
Os testes para esse pacote são conhecidos por estarem quebrados. Para testar a instalação de qualquer maneira, execute pytest.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
Iniconfig é um módulo analisador de arquivo "INI" pequeno e simples.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/i/iniconfig/iniconfig-2.3.0.tar.gz
Soma de verificação MD5 da transferência: 5c1d9c21275feb3da71400bf716edd72
Tamanho da transferência: 24 KB
Espaço em disco estimado exigido: 304 KB
Tempo de construção estimado: menos que 0,1 UPC
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user iniconfig
Para testar os resultados, emita: pytest
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O módulo maturin fornece um sistema de construção para binários Rust e crates gerados a partir de pacotes Python.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://github.com/PyO3/maturin/archive/v1.14.1/maturin-1.14.1.tar.gz
Soma de verificação MD5 da transferência: ed60ce01916c36311fa8752b7af00b67
Tamanho da transferência: 759 KB
Espaço em disco estimado exigido: 537 MB (adicionar 6,1 GB para os testes)
Tempo de construção estimado: 1,3 UPC (incluindo tempo de transferência; adicionar 2,5 UPC para testes com tempo de transferência)
rustc-1.97.1 e setuptools_rust-1.12.1
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user maturin
Para testar a instalação, emita:
python3 -m venv --system-site-packages testenv && testenv/bin/pip3 install cffi pycparser virtualenv && PATH=$PWD/testenv/bin:$PATH cargo test
Seis testes, errors::pypi_compatibility_unsupported_target,
integration::integration_cffi_cases::case_2_cffi_mixed,
integration::integration_wasm_hello_world,
sdist::external_python_source_sdist,
sdist::lib_with_parent_workspace_path_dep_sdist
e sdist::pyo3_mixed_include_exclude_sdist são
conhecidos por falharem.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
"Markdown" é um analisador "Python" para a especificação "Markdown" de John Gruber.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/M/Markdown/markdown-3.10.2.tar.gz
Soma de verificação MD5 da transferência: ec7bae2cc261dcb2c9a27271b60d40d4
Tamanho da transferência: 364 KB
Espaço em disco estimado exigido: 21 MB (com testes)
Tempo de construção estimado: menos que 0,1 UPC (com testes)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user Markdown
Supondo que pytest-9.1.1 e PyYAML-6.0.3 estejam instalados e a outra dependência opcional não esteja, a instalação pode ser testada com:
python3 -m venv --system-site-packages testenv && source testenv/bin/activate && pip3 install coverage && python3 /usr/bin/pytest --ignore=tests/test_syntax/extensions/test_md_in_html.py deactivate
As instruções acima ignoram o teste test_md_in_html porque ele é incompatível com
pytest-9.0 e posterior. Um teste, test_apis.py::TestConvertFile::testFileNames,
gerará um aviso de descontinuação por causa do Python 3.14.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--system-site-packages:
Permita que o módulo venv do Python3 acesse o diretório /usr/lib/python3.14/site-packages do sistema
instalado.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O módulo "Meson_python" contém uma estrutura de retaguarda de construção "Python" ("PEP" 517) para projetos "Meson".
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/m/meson_python/meson_python-0.20.0.tar.gz
Soma de verificação MD5 da transferência: 032ed60b1d86c448331fc0a2ba81f499
Tamanho da transferência: 104 KB
Espaço em disco estimado exigido: 20 MB (com testes)
Tempo de construção estimado: menos que 0,1 UPC
build-1.5.1, cython-3.2.9, git-2.55.0, pytest-9.1.1 e pytest-mock
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user meson_python
Para testar a instalação, certifique-se de que git-2.55.0, patchelf-0.19.1 e pytest-9.1.1 estejam instalados e, em seguida,
emita (HOME= impede que o arquivo
.gitconfig no diretório inicial
interfira nos testes):
python3 -m venv --system-site-packages testenv && testenv/bin/pip3 install --group=test && HOME= testenv/bin/python -m pytest
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--system-site-packages:
Permita que o módulo venv do Python3 acesse o diretório /usr/lib/python3.14/site-packages do sistema
instalado.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
Msgpack é um formato de serialização binária eficiente. Ele te permite trocar dados entre várias linguagens, como JSON. Mas é mais rápido e menor. Esse pacote fornece ligações CPython para leitura e escrita de dados do Msgpack.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/m/msgpack/msgpack-1.2.1.tar.gz
Soma de verificação MD5 da transferência: e0a9c82423574f99314ccd1ed77b8c67
Tamanho da transferência: 180 KB
Espaço em disco estimado exigido: 4,1 MB (adicionar 0,3 MB para os testes)
Tempo de construção estimado: menos que 0,1 UPC
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user msgpack
Para testar a instalação, emita pytest.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
"Pathspec" é uma biblioteca de utilitários para correspondência de padrões de caminhos de arquivos.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/p/pathspec/pathspec-1.1.1.tar.gz
Soma de verificação MD5 da transferência: c762d0a00d6cfc9de003e02d5072b26a
Tamanho da transferência: 136 KB
Espaço em disco estimado exigido: 1,7 MB (com testes)
Tempo de construção estimado: menos que 0,1 UPC (com testes)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user pathspec
Para testar a instalação, emita "pytest".
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O pacote Pluggy oferece a usantes a capacidade de estender ou modificar o comportamento de um programa anfitrião instalando um plugin para esse programa. O código do plugin será executado como parte da execução normal do programa, mudando ou aprimorando certos aspectos dele. Em essência, pluggy habilita a ligação de funções, de modo que um(a) usante consiga construir sistemas “plugáveis”.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/p/pluggy/pluggy-1.6.0.tar.gz
Soma de verificação MD5 da transferência: 54391218af778acb006c2d915085d469
Tamanho da transferência: 68 KB
Espaço em disco estimado exigido: 588 KB (adicionar 18 MB para testes)
Tempo de construção estimado: menos que 0,1 UPC (com testes)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user pluggy
Para testar a instalação, emita: pytest.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
Poetry-core é uma estrutura de retaguarda de construção extensível e em conformidade com padrões para módulos Python.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/p/poetry_core/poetry_core-2.4.1.tar.gz
Soma de verificação MD5 da transferência: 6c4fb726467b1e270892f51c54c392ba
Tamanho da transferência: 404 KB
Espaço em disco estimado exigido: 10 MB (adicionar 28 MB para os testes)
Tempo de construção estimado: menos que 0,1 UPC (0,3 UPC para testes)
pytest-9.1.1, build-1.5.1, pytest-cov, pytest-mock e virtualenv
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user poetry-core
Para testar a instalação, assegure-se de que pytest-9.1.1 e build-1.5.1 estejam instalados, então emita:
python3 -m venv --system-site-packages testenv &&
testenv/bin/pip3 install pytest-{cov,mock} tomli-w virtualenv &&
testenv/bin/python -m pytest
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
Pyproject_Hooks é uma biblioteca
de baixo nível para chamar estruturas de retaguarda de construção
em projetos baseados em pyproject.toml.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/p/pyproject-hooks/pyproject_hooks-1.2.0.tar.gz
Soma de verificação MD5 da transferência: ed3dd1b984339e83e35f676d7169c192
Tamanho da transferência: 19 KB
Espaço em disco estimado exigido: 520 KB (14 MB com testes)
Tempo de construção estimado: menos que 0,1 UPC (com testes)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user pyproject_hooks
Supondo que pytest-9.1.1 esteja instalado, mas a outra dependência opcional não esteja, a instalação pode ser testada com os seguintes comandos:
python3 -m venv --system-site-packages testenv && source testenv/bin/activate && pip3 install testpath && python3 -m pytest deactivate
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--system-site-packages:
Permita que o módulo venv do Python3 acesse o diretório /usr/lib/python3.14/site-packages do sistema
instalado.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O módulo "Pyproject-Metadata" contém uma classe de dados para metadados "PEP" 621 com suporte para geração de “metadados centrais” ("PEP" 643).
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/p/pyproject-metadata/pyproject_metadata-0.12.1.tar.gz
Soma de verificação MD5 da transferência: d44c15fd176128acd9497af2512085a0
Tamanho da transferência: 44 KB
Espaço em disco estimado exigido: 700 KB
Tempo de construção estimado: menos que 0,1 UPC
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user pyproject-metadata
Para testar a instalação, assegure-se de que pytest-9.1.1 esteja instalado e execute:
python3 -m venv --system-site-packages testenv && testenv/bin/pip3 install exceptiongroup && testenv/bin/python3 -m pytest
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
A biblioteca "Pytz" traz a base de dados "tz" da "IANA" para o "Python". Ela permite cálculos de fuso horário precisos e entre plataformas.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/p/pytz/pytz-2026.2.tar.gz
Soma de verificação MD5 da transferência: ac9ab5e07d91fea1f15cbf50c18f29d9
Tamanho da transferência: 316 KB
Espaço em disco estimado exigido: 6,3 MB (com testes)
Tempo de construção estimado: menos que 0,1 UPC (com testes)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user pytz
Para testar a instalação, execute "pytest". Uns poucos avisos são emitidos.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
Roman-numerals é uma biblioteca Python para manipular numerais romanos bem formados.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/r/roman-numerals/roman_numerals-4.1.0.tar.gz
Soma de verificação MD5 da transferência: 0154d3518651ec46fb0ad1dfbdf86348
Tamanho da transferência: 12 KB
Espaço em disco estimado exigido: 320 KB
Tempo de construção estimado: menos que 0,1 UPC
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user roman-numerals
Para testar a instalação, emita: pytest.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O módulo semantic_version traz uma pequena biblioteca para lidar com o padrão de Versionamento Semântico em Python.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/s/semantic_version/semantic_version-2.10.0.tar.gz
Soma de verificação MD5 da transferência: e48abef93ba69abcd4eaf4640edfc38b
Tamanho da transferência: 52 KB
Espaço em disco estimado exigido: 656 KB (com testes)
Tempo de construção estimado: menos que 0,1 UPC (com testes)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user semantic_version
Para testar a instalação, execute pytest. Existem mais que 500 avisos emitidos devido à sintaxe obsoleta com versões mais recentes do Python.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O módulo setuptools_rust fornece um plugin para setuptools que permite a compilação de extensões Python em Rust.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/s/setuptools_rust/setuptools_rust-1.12.1.tar.gz
Soma de verificação MD5 da transferência: 90ce501aabce2a859e19a213985288ea
Tamanho da transferência: 304 KB
Espaço em disco estimado exigido: 3,9 MB (com testes)
Tempo de construção estimado: menos que 0,1 UPC (com testes)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user setuptools_rust
Para testar a instalação, emita: pytest --doctest-modules setuptools_rust tests. Um aviso estará presente acerca de uma descontinuação da API.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O pacote "Setuptools_scm" é usado para extrair versões de pacotes "Python" a partir dos metadados "git" ou "hg" em vez de declará-los.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/s/setuptools_scm/setuptools_scm-10.1.2.tar.gz
Soma de verificação MD5 da transferência: fc7dfeae0b61636e3705547acc9f3276
Tamanho da transferência: 68 KB
Espaço em disco estimado exigido: 1,6 MB (adicionar 118 MB para os testes)
Tempo de construção estimado: menos que 0,1 UPC (adicionar 0,4 UPC para testes)
build-1.5.1, git-2.55.0, mercurial-7.2.4, pytest-9.1.1, Sudo-1.9.17p2, pytest-timeout, rich, ruff, mypy, griffe e flake8
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user setuptools_scm
Para testar a instalação, certifique-se de que pytest-9.1.1 e as outras dependências
opcionais estejam instaladas e execute (HOME= impede que o arquivo .gitconfig no diretório inicial interfira nos
testes):
python3 -m venv --system-site-packages testenv && testenv/bin/pip3 install --group test && TZ=UTC HOME= testenv/bin/python3 -m pytest
Se git-2.55.0 e (ou) mercurial-7.2.4 não estiverem instalados, os testes dependentes do(s) ausente(s) serão ignorados. Alguns testes possivelmente invoquem Sudo-1.9.17p2 e solicitem uma senha.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
"Smartypants" traduz caracteres de pontuação "ASCII" simples em entidades "HTML" de pontuação tipográfica “inteligente”.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/s/smartypants/smartypants-2.0.2.tar.gz
Soma de verificação MD5 da transferência: 3149badecd0771c80ee9db4d09695edd
Tamanho da transferência: 17 KB
Espaço em disco estimado exigido: 344 KB
Tempo de construção estimado: menos que 0,1 UPC
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Esse pacote não vem com uma suíte de teste funcional.
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user smartypants
Para testar os resultados, emita:
cp /usr/bin/smartypants . && pytest
Um teste, SetupTestCase::test_long_description, é
conhecido por imprimir um aviso acerca de próximas mudanças no
docutils.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O pacote Snowballstemmer é uma pequena linguagem de processamento de sequências de caracteres para criar algoritmos de remoção de radical [de palavras] para uso em Recuperação de Informação, mais uma coleção de algoritmos de remoção de radical [de palavras] implementados usando-a. O removedor de radical [de palavras] mapeia diferentes formas da mesma palavra para um “radical” comum — por exemplo, o removedor inglês de radical [de palavras] mapeia connection, connections, connective, connected e connecting para connect. Executar-se uma busca por connected também encontraria documentos que tenham somente as outras formas.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/s/snowballstemmer/snowballstemmer-3.1.1.tar.gz
Soma de verificação MD5 da transferência: 6f838ab3e97baba9ed72ef64966ba4a0
Tamanho da transferência: 124 KB
Espaço em disco estimado exigido: 2,0 MB
Tempo de construção estimado: menos que 0,1 UPC
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Esse pacote não vem com uma suíte de teste.
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user snowballstemmer
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O pacote "Sphinxcontrib-applehelp" é uma extensão "Sphinx" que produz livros de ajuda da "Apple".
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/s/sphinxcontrib-applehelp/sphinxcontrib_applehelp-2.0.0.tar.gz
Soma de verificação MD5 da transferência: e16bb1d6199f686d411c180e64a8e831
Tamanho da transferência: 20 KB
Espaço em disco estimado exigido: 1,0 MB (com testes)
Tempo de construção estimado: menos que 0,1 UPC
pytest-9.1.1 e sphinx-9.1.0 (dependência circular)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user sphinxcontrib-applehelp
Para testar a instalação, execute pytest.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O pacote "Sphinxcontrib-devhelp" é uma extensão "Sphinx" que produz documentos Devhelp.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/s/sphinxcontrib-devhelp/sphinxcontrib_devhelp-2.0.0.tar.gz
Soma de verificação MD5 da transferência: 79ef5937b8397f724f4fb065073cd24c
Tamanho da transferência: 16 KB
Espaço em disco estimado exigido: 984 MB (com testes)
Tempo de construção estimado: menos que 0,1 UPC (com testes)
pytest-9.1.1 e sphinx-9.1.0 (dependência circular)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user sphinxcontrib-devhelp
Para testar a instalação, execute pytest.
A suíte de teste imprimirá um aviso acerca das próximas mudanças no sphinx-11.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O pacote "Sphinxcontrib-htmlhelp" é uma extensão "Sphinx" que renderiza arquivos de ajuda "HTML".
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/s/sphinxcontrib-htmlhelp/sphinxcontrib_htmlhelp-2.1.0.tar.gz
Soma de verificação MD5 da transferência: 1326f55f6bea49ab6a846c0088bc369e
Tamanho da transferência: 24 KB
Espaço em disco estimado exigido: 1,2 MB (com testes)
Tempo de construção estimado: menos que 0,1 UPC (com testes)
pytest-9.1.1, sphinx-9.1.0 (dependência circular) e html5lib-1.1
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user sphinxcontrib-htmlhelp
Se as dependências opcionais estiverem instaladas, o pacote pode ser testado com os seguintes comandos. O primeiro comando corrige um problema com a API removida no Sphinx.
sed -i 's/keyword/pair: keyword;/' tests/roots/test-chm/index.rst && pytest
Os testes produzirão um aviso de descontinuação acerca das próximas mudanças no sphinx-11.x.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O pacote "Sphinxcontrib-jquery" é uma extensão "Sphinx" que inclui "jQuery" nos lançamentos mais recentes do "Sphinx".
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/s/sphinxcontrib-jquery/sphinxcontrib-jquery-4.1.tar.gz
Soma de verificação MD5 da transferência: 46ea52845b17343ed6c61e6963fb265d
Tamanho da transferência: 120 KB
Espaço em disco estimado exigido: 552 KB
Tempo de construção estimado: menos que 0,1 UPC
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Esse pacote não vem com uma suíte de teste funcional.
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user sphinxcontrib-jquery
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O pacote "Sphinxcontrib-jsmath" é uma extensão "Sphinx" que renderiza matemática de exibição em "HTML" via "JavaScript".
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/s/sphinxcontrib-jsmath/sphinxcontrib-jsmath-1.0.1.tar.gz
Soma de verificação MD5 da transferência: e45179f0a3608b6766862e0f34c23b62
Tamanho da transferência: 5,7 KB
Espaço em disco estimado exigido: 324 KB (com testes)
Tempo de construção estimado: menos que 0,1 UPC (com testes)
pytest-9.1.1 e sphinx-9.1.0 (dependência circular)
Primeiro, corrija várias incompatibilidades com Sphinx-9.1 e pytest-9.0.2:
patch -Np1 -i ../sphinxcontrib-jsmath-1.0.1-sphinx9_fixes-1.patch
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user sphinxcontrib-jsmath
A instalação pode ser testada com o seguinte comando:
pytest
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O pacote "Sphinxcontrib-qthelp" é uma extensão "Sphinx" que produz documentos "QtHelp".
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/s/sphinxcontrib-qthelp/sphinxcontrib_qthelp-2.0.0.tar.gz
Soma de verificação MD5 da transferência: ed4f32003b71a54ac3d68aa651cb6573
Tamanho da transferência: 20 KB
Espaço em disco estimado exigido: 18 MB (com testes)
Tempo de construção estimado: menos que 0,1 UPC (com testes)
pytest-9.1.1, sphinx-9.1.0 (dependência circular) e defusedxml
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user sphinxcontrib-qthelp
A instalação pode ser testada com os seguintes comandos:
python3 -m venv --system-site-packages testenv && testenv/bin/pip3 install defusedxml && testenv/bin/python -m pytest
A suíte de teste imprimirá avisos acerca das próximas mudanças no Sphinx.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--system-site-packages:
Permita que o módulo venv do Python3 acesse o diretório /usr/lib/python3.14/site-packages do sistema
instalado.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O pacote "Sphinxcontrib-serializinghtml" é uma extensão "Sphinx" que produz arquivos "HTML" “serializados” ("json" e "pickle").
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/s/sphinxcontrib_serializinghtml/sphinxcontrib_serializinghtml-2.0.0.tar.gz
Soma de verificação MD5 da transferência: b536ce248d5ca134a30018692a17c6ca
Tamanho da transferência: 16 KB
Espaço em disco estimado exigido: 1,1 MB (com testes)
Tempo de construção estimado: menos que 0,1 UPC (com testes)
pytest-9.1.1 e sphinx-9.1.0 (dependência circular)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user sphinxcontrib-serializinghtml
Para testar a instalação, primeiro instale sphinx-9.1.0, a seguir execute pytest. A suíte de teste imprimirá dois avisos acerca das próximas mudanças no Sphinx.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
Tomlkit é uma estrutura de retaguarda de construção extensível e em conformidade com padrões para módulos Python.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/t/tomlkit/tomlkit-0.15.1.tar.gz
Soma de verificação MD5 da transferência: 8e5245fd4099c9a6f99774b24a4591ae
Tamanho da transferência: 176 KB
Espaço em disco estimado exigido: 5,7 MB (adicionar 17 MB para os testes)
Tempo de construção estimado: menos que 0,1 UPC (com testes)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user tomlkit
Para testar a instalação, assegure-se de que pytest-9.1.1 esteja instalado, então emita:
python3 -m venv --system-site-packages testenv && testenv/bin/pip3 install pytest-cov && testenv/bin/python -m pytest
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
Trove-Classifiers é uma
biblioteca Python que abrange todos os classificadores PyPI
válidos usados para categorizar projetos e lançamentos de acordo
com PEP 301, por exemplo Topic :: System ::
Filesystems e Development Status ::
6 - Mature.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/t/trove_classifiers/trove_classifiers-2026.6.1.19.tar.gz
Soma de verificação MD5 da transferência: fb231b2e9492a5d34fb9bec0250f0f55
Tamanho da transferência: 20 KB
Espaço em disco estimado exigido: 540 KB
Tempo de construção estimado: menos que 0,1 UPC
Primeiro, codifique rigidamente a versão do pacote em
setup.py para contornar um problema
que faz com que a roda gerada contenha uma sequência incorreta de
caracteres de versão quando o módulo calver não estiver instalado:
sed -i '/calver/s/^/#/;$iversion="2026.6.1.19"' setup.py
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user trove-classifiers
Para testar a instalação, emita: pytest.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
"Typogrify" fornece filtros para aprimorar a tipografia da "web", incluindo suporte para modelos "Django" e "Jinja".
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/t/typogrify/typogrify-2.1.0.tar.gz
Soma de verificação MD5 da transferência: 7cc9a0a1de988329add3982519dc7971
Tamanho da transferência: 13 KB
Espaço em disco estimado exigido: 404 KB
Tempo de construção estimado: menos que 0,1 UPC
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Esse pacote não vem com uma suíte de teste.
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user typogrify
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O módulo Urllib3 é um cliente HTTP, poderoso e amigável para com o(a) usante, para Python. Ele traz muitos recursos críticos que estão ausentes nas bibliotecas padrão do Python.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/u/urllib3/urllib3-2.7.0.tar.gz
Soma de verificação MD5 da transferência: e79707b798a66c8165c9c441440f4e80
Tamanho da transferência: 424 KB
Espaço em disco estimado exigido: 3,5 MB (adicionar 123 MB para os testes)
Tempo de construção estimado: menos que 0,1 UPC (0,6 UPC para testes)
pytest-9.1.1, httpx, hypercorn, mock, PySocks, pytest-timeout, python-dateutil, quart, quart-trio, tornado, trio e trustme
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user urllib3
Supondo que pytest-9.1.1 esteja instalado, mas as outras dependências opcionais não estejam, a instalação pode ser testada com os seguintes comandos:
python3 -m venv --system-site-packages testenv && source testenv/bin/activate && pip3 install --group dev && python3 /usr/bin/pytest --timeout 10 deactivate
Ao menos 46 falhas são esperadas com as instruções acima. Existem
vários motivos. Primeiro, o fluxo de desenvolvimento usa uma
versão remendada do módulo hypercorn para a própria testagem
deles(as), que só pode ser obtida via git em https://github.com/urllib3/hypercorn.git,
na revisão “urllib3-changes”, e deveria ser instalada
primeiro no ambiente virtual. Segundo, parece que a suíte de
teste não tem sido adaptada para versões recentes do Python e
para versões recentes dos módulos externos do Python. Em
particular, alguns testes travarão, de modo que pytest precisa da chave
--timeout.
Os testes estão atualmente quebrados com OpenSSL-4, pois o módulo pyopenssl que é baixado e instalado no ambiente virtual não foi ajustado para mudanças exigidas pelo OpenSSL-4.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--system-site-packages:
Permita que o módulo venv do Python3 acesse o diretório /usr/lib/python3.14/site-packages do sistema
instalado.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O módulo uv_build fornece a estrutura de retaguarda de construção PEP 517 originária do sistema de gerenciamento de pacotes 'uv' do Python.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/u/uv_build/uv_build-0.11.24.tar.gz
Soma de verificação MD5 da transferência: f537ded461369ed76aec64e5d2e0269d
Tamanho da transferência: 392 KB
Espaço em disco estimado exigido: 445 MB
Tempo de construção estimado: 0,9 UPC
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Esse pacote não vem com uma suíte de teste.
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user uv_build
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
vcs_versioning fornece uma funcionalidade essencial para setuptools_scm, que permite que esse módulo configure adequadamente metadados de controle de versão.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/v/vcs_versioning/vcs_versioning-2.2.4.tar.gz
Soma de verificação MD5 da transferência: 4379f311792d41c845f9b86975b1be18
Tamanho da transferência: 132 KB
Espaço em disco estimado exigido: 2,8 MB
Tempo de construção estimado: menos que 0,1 UPC (adicionar 1,2 UPC para testes)
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user vcs_versioning
Para testar a instalação, emita (HOME= impede que o arquivo .gitconfig no diretório lar interfira nos
testes):
python3 -m venv --system-site-packages testenv && testenv/bin/pip3 install pytest-timeout && HOME= testenv/bin/python3 -m pytest
A suíte de teste possivelmente cause entradas do teclado não exibidas na tela em absoluto (porém, você ainda consegue executar qualquer comando, se conseguir digitá-lo corretamente). Execute o comando reset para corrigir tal problema.
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
O módulo webencodings é uma implementação Python do padrão de codificação WHATWG.
Esse pacote é conhecido por construir e funcionar adequadamente usando-se uma plataforma LFS 13.1.
Transferência (HTTP): https://files.pythonhosted.org/packages/source/w/webencodings/webencodings-0.5.1.tar.gz
Soma de verificação MD5 da transferência: 32f6e261d52e57bf7e1c4d41546d15b8
Tamanho da transferência: 12 KB
Espaço em disco estimado exigido: 164 KB
Tempo de construção estimado: menos que 0,1 UPC
Construa o módulo:
pip3 wheel -w dist --no-build-isolation --no-deps --no-cache-dir $PWD
Agora, como o(a) usante root:
pip3 install --no-index --find-links dist --no-user webencodings
-w dist: constrói o
"wheel" apropriado para esse módulo no diretório dist.
--no-build-isolation:
informa ao pip3 para executar a construção no ambiente do sistema
em vez de criar um ambiente temporário de construção.
--no-deps: impede o pip3
de construir wheels para as dependências do projeto.
--no-index: ignora o
índice do pacote (olhando apenas para URLs do --find-links).
--find-links dist:
procura linques para arquivamentos, como arquivos wheel (.whl),
no diretório dist.
--no-cache-dir:
Desabilita o cache para evitar um aviso ao instalar como o(a)
usante root.
--no-user: Evite executar
erroneamente o comando de instalação como um(a) usante não root.
--upgrade: Atualize o pacote para a
versão mais recente disponível. Essa opção é usada com o comando
de instalação se uma versão do pacote já estiver instalada.
--force-reinstall: Reinstale o pacote
mesmo se ele estiver atualizado. Essa opção é usada com o comando
de instalação se reinstalar-se o pacote ou reverter-se para uma
versão anterior do pacote.
--no-deps: Não instale dependências
do pacote. Essa opção possivelmente seja necessária com as opções
--upgrade ou --force-reinstall.
Last updated on